/**
 * This file is part of CellularQt
 *
 * Copyright (C) 2009 Nokia Corporation. All rights reserved.
 */

#ifndef CALLTIMERS_H
#define CALLTIMERS_H

#include <QtCore/QObject>

#include "libcellular-qt_global.h"

namespace Cellular
{

class CallTimersPrivate;

//! Call timers.
/*!
 * This class provides access to the call timers.
 */
//! @credential %Cellular resource token required
class CELLULAR_QT_EXPORT CallTimers : public QObject
{

Q_OBJECT

public:
    //! Call timers, in seconds
    struct CallTimersInfo {
        uint last; //!< Current or last call duration; measured from the beginning of the first call until the present time or until the last call ends
        uint dialled; //!< Dialled calls duration
        uint received; //!< Received calls duration
        uint total; //!< Total calls duration
    };

public:
    CallTimers(QObject *parent=0);
    ~CallTimers();

    //! Get the current call timers
    CallTimersInfo timers() const;

    //! Clear the current call timers
    void clearTimers() const;

    //! Returns the time interval in seconds between timersUpdated() signals
    uint callUpdateTime() const;

    //! Sets the time interval in seconds between timersUpdated() signals
    void setCallUpdateTime(uint seconds) const;

    //! Check validity of class instance.
    bool isValid() const;
signals:
    //! Emitted at settable intervals when there is a running call
    void timersUpdated(CallTimers::CallTimersInfo timers);

private:
    CallTimersPrivate *d;
};

}

#endif  /* !CALLTIMERS_H */
