/**
 * This file is part of CellularQt
 *
 * Copyright (C) 2009-2010 Nokia Corporation. All rights reserved.
 */

#ifndef PHONEINFO_H
#define PHONEINFO_H

#include <QtCore/QObject>
#include <QtCore/QString>

#include "libcellular-qt_global.h"

namespace Cellular
{

class PhoneInfoPrivate;

//! Phone information.
/*!
 * This class is used for querying various Nokia Cellular modem
 * related information, i.e., the International Mobile Equipment
 * Identity (IMEI) number, modem software versions, and the HSXPA
 * setting.
 */
class CELLULAR_QT_EXPORT PhoneInfo : public QObject
{

    Q_OBJECT

public:
    PhoneInfo(QObject *parent=0);
    ~PhoneInfo();

    /*! This enum represents the status of the availability of the
     *  HSXPA (HSDPA and/or HSUPA) settings. */
    enum SettingStatus
    {
	SettingUnavailable = -1, //!< Setting is currently unavailable.
	Disabled = 0,            //!< HSXPA disabled.
	Enabled                  //!< HSXPA enabled.
    };

    //! get the IMEI number of the device. (string of 15 bytes).
    QString imeiNumber() const;
    //! get the MCU SW version of the cellular modem.
    QString mcuSWVersion() const;
    //! get the DSP SW version of the cellular modem.
    QString dspSWVersion() const;
    //! get the HSxPA feature setting information.
    SettingStatus hsxpaSetting() const;
    //! Check validity of readings
    bool isValid() const;

private:
    PhoneInfoPrivate *d;
};

}
#endif  /* !PHONEINFO_H */
